@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -204,7 +204,7 @@ void qjackctlSetup::saveSetup (void)
 {
 	// Save all settings and options...
 	m_settings.beginGroup("/Program");
-	m_settings.setValue("/Version", CONFIG_BUILD_VERSION);
+	m_settings.setValue("/Version", PROJECT_VERSION);
 	m_settings.endGroup();
 
 	m_settings.beginGroup("/Presets");
@@ -707,11 +707,9 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 		sServerName = sVal;
 	}
 
-	foreach(const QString& sArg, parser.positionalArguments()) {
+	foreach (const QString& sArg, parser.positionalArguments()) {
 		if (sArg != "-T" && sArg != "-ndefault") {
-			if (iCmdArgs > 0)
-				sCmdLine += ' ';
-			sCmdLine += sArg;
+			cmdLine.append(sArg);
 			++iCmdArgs;
 		}
 	}
@@ -724,14 +722,14 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 
 	for (int i = 1; i < argc; ++i) {
 
+		QString sArg = args.at(i);
+
 		if (iCmdArgs > 0) {
-			sCmdLine += ' ';
-			sCmdLine += args.at(i);
+			sCmdArgs.append(sArg);
 			++iCmdArgs;
 			continue;
 		}
 
-		QString sArg = args.at(i);
 		QString sVal;
 		const int iEqual = sArg.indexOf('=');
 		if (iEqual >= 0) {
@@ -788,12 +786,12 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 		#endif
 			out << QString("%1: %2\n")
 				.arg(QJACKCTL_TITLE)
-				.arg(CONFIG_BUILD_VERSION);
+				.arg(PROJECT_VERSION);
 			return false;
 		}	// FIXME: Avoid auto-start jackd stuffed args!
 		else if (sArg != "-T" && sArg != "-ndefault") {
 			// Here starts the optional command line...
-			sCmdLine += sArg;
+			cmdLine.append(sArg);
 			++iCmdArgs;
 		}
 	}
@@ -801,10 +799,8 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 #endif
 
 	// HACK: If there's a command line, it must be spawned on background...
-	if (iCmdArgs > 0) {
-		sCmdLine += ' ';
-		sCmdLine += '&';
-	}
+	if (iCmdArgs > 0)
+		cmdLine.append("&");
 
 	// Alright with argument parsing.
 	return true;
